@@ -10,6 +10,7 @@ use std::fmt;
 use std::i32;
 use std::marker::PhantomData;
 use std::ops::Deref;
+use std::os::raw::c_char;
 use std::ptr;
 use std::rc::Rc;
 use std::slice;
@@ -316,7 +317,11 @@ impl Record {
     pub fn set_id(&mut self, id: &[u8]) -> Result<()> {
         let c_str = ffi::CString::new(id).unwrap();
         if unsafe {
-            htslib::bcf_update_id(self.header().inner, self.inner, c_str.as_ptr() as *mut i8)
+            htslib::bcf_update_id(
+                self.header().inner,
+                self.inner,
+                c_str.as_ptr() as *mut c_char,
+            )
         } == 0
         {
             Ok(())
@@ -329,7 +334,11 @@ impl Record {
     pub fn clear_id(&mut self) -> Result<()> {
         let c_str = ffi::CString::new(&b"."[..]).unwrap();
         if unsafe {
-            htslib::bcf_update_id(self.header().inner, self.inner, c_str.as_ptr() as *mut i8)
+            htslib::bcf_update_id(
+                self.header().inner,
+                self.inner,
+                c_str.as_ptr() as *mut c_char,
+            )
         } == 0
         {
             Ok(())
@@ -341,8 +350,13 @@ impl Record {
     /// Add the ID string (the ID field is semicolon-separated), checking for duplicates.
     pub fn push_id(&mut self, id: &[u8]) -> Result<()> {
         let c_str = ffi::CString::new(id).unwrap();
-        if unsafe { htslib::bcf_add_id(self.header().inner, self.inner, c_str.as_ptr() as *mut i8) }
-            == 0
+        if unsafe {
+            htslib::bcf_add_id(
+                self.header().inner,
+                self.inner,
+                c_str.as_ptr() as *mut c_char,
+            )
+        } == 0
         {
             Ok(())
         } else {
@@ -385,7 +399,7 @@ impl Record {
         if flt_id.is_pass() && self.inner().d.n_flt == 0 {
             return true;
         }
-        let id = match flt_id.id_from_header(&self.header()) {
+        let id = match flt_id.id_from_header(self.header()) {
             Ok(i) => *i,
             Err(_) => return false,
         };
@@ -580,9 +594,9 @@ impl Record {
             .iter()
             .map(|vec| ffi::CString::new(*vec).unwrap())
             .collect();
-        let mut ptrs: Vec<*const i8> = cstrings
+        let mut ptrs: Vec<*const c_char> = cstrings
             .iter()
-            .map(|cstr| cstr.as_ptr() as *const i8)
+            .map(|cstr| cstr.as_ptr() as *const c_char)
             .collect();
         if unsafe {
             htslib::bcf_update_alleles(
@@ -822,7 +836,7 @@ impl Record {
             if htslib::bcf_update_format(
                 self.header().inner,
                 self.inner,
-                tag_c_str.as_ptr() as *mut i8,
+                tag_c_str.as_ptr() as *mut c_char,
                 data.as_ptr() as *const ::std::os::raw::c_void,
                 data.len() as i32,
                 ht as i32,
@@ -869,8 +883,8 @@ impl Record {
             if htslib::bcf_update_format_string(
                 self.header().inner,
                 self.inner,
-                tag_c_str.as_ptr() as *mut i8,
-                c_ptrs.as_slice().as_ptr() as *mut *const i8,
+                tag_c_str.as_ptr() as *mut c_char,
+                c_ptrs.as_slice().as_ptr() as *mut *const c_char,
                 data.len() as i32,
             ) == 0
             {
@@ -915,7 +929,7 @@ impl Record {
             if htslib::bcf_update_info(
                 self.header().inner,
                 self.inner,
-                tag_c_str.as_ptr() as *mut i8,
+                tag_c_str.as_ptr() as *mut c_char,
                 data.as_ptr() as *const ::std::os::raw::c_void,
                 data.len() as i32,
                 ht as i32,
@@ -970,7 +984,7 @@ impl Record {
             if htslib::bcf_update_info(
                 self.header().inner,
                 self.inner,
-                tag_c_str.as_ptr() as *mut i8,
+                tag_c_str.as_ptr() as *mut c_char,
                 c_str.as_ptr() as *const ::std::os::raw::c_void,
                 len as i32,
                 ht as i32,
@@ -1231,7 +1245,7 @@ impl<'a, 'b, B: BorrowMut<Buffer> + Borrow<Buffer> + 'b> Info<'a, B> {
             htslib::bcf_get_info_values(
                 self.record.header().inner,
                 self.record.inner,
-                c_str.as_ptr() as *mut i8,
+                c_str.as_ptr() as *mut c_char,
                 &mut self.buffer.borrow_mut().inner,
                 &mut n,
                 data_type as i32,
@@ -1346,7 +1360,7 @@ impl<'a, 'b, B: BorrowMut<Buffer> + Borrow<Buffer> + 'b> Format<'a, B> {
             htslib::bcf_get_fmt(
                 record.header().inner,
                 record.inner,
-                c_str.as_ptr() as *mut i8,
+                c_str.as_ptr() as *mut c_char,
             )
         };
         Format {
@@ -1382,7 +1396,7 @@ impl<'a, 'b, B: BorrowMut<Buffer> + Borrow<Buffer> + 'b> Format<'a, B> {
             htslib::bcf_get_format_values(
                 self.record.header().inner,
                 self.record.inner,
-                c_str.as_ptr() as *mut i8,
+                c_str.as_ptr() as *mut c_char,
                 &mut self.buffer.borrow_mut().inner,
                 &mut n,
                 data_type as i32,
