@@ -110,17 +110,12 @@
 
 #[macro_use]
 extern crate custom_derive;
-extern crate libc;
+
 #[macro_use]
 extern crate newtype_derive;
 
 #[cfg(feature = "serde_feature")]
 extern crate serde;
-#[cfg(feature = "serde_feature")]
-extern crate serde_bytes;
-
-#[cfg(all(test, feature = "serde_feature"))]
-extern crate bincode;
 
 #[cfg(test)] // <-- not needed in examples + integration tests
 #[macro_use]
